@@ -13,7 +13,7 @@ use Socket qw(
     inet_aton inet_ntoa pack_sockaddr_in unpack_sockaddr_in
 );
 
-our $VERSION = '1.89_04';
+our $VERSION = '1.89_05';
 
 my %PROTOS = (
     tcp => SOCK_STREAM,
@@ -134,7 +134,7 @@ Test::Net::SSLeay::Socket - Socket class for the Net-SSLeay test suite
 
 =head1 VERSION
 
-This document describes version 1.89_04 of Test::Net::SSLeay::Socket.
+This document describes version 1.89_05 of Test::Net::SSLeay::Socket.
 
 =head1 SYNOPSIS
 
@@ -276,28 +276,9 @@ from Net-SSLeay test scripts.
 =head1 BUGS
 
 If you encounter a problem with this module that you believe is a bug, please
-report it in one of the following ways:
-
-=over 4
-
-=item *
-
-create a new issue under the
-L<Net-SSLeay GitHub project|https://github.com/radiator-software/p5-net-ssleay/issues/new>;
-
-=item *
-
-open a ticket using the
-L<CPAN RT bug tracker's web interface|https://rt.cpan.org/Public/Bug/Report.html?Queue=Net-SSLeay>;
-
-=item *
-
-send an email to the
-L<CPAN RT bug tracker's bug-reporting system|mailto:bug-Net-SSLeay@rt.cpan.org>.
-
-=back
-
-Please make sure your bug report includes the following information:
+L<create a new issue|https://github.com/radiator-software/p5-net-ssleay/issues/new>
+in the Net-SSLeay GitHub repository. Please make sure your bug report includes
+the following information:
 
 =over
 
